import { select, 
        csv, 
        scaleLinear, 
        max,
        scaleBand, 
        axisLeft, 
        axisBottom,
        format} from 'd3';

const svg = select('svg')

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
 const xValue = d => d.COVID19
 const yValue = d => d.country
 const margin = {top:20, right:20, bottom:100, left:100}
 const innerWidth = width - margin.left - margin.right;
 const innerHeight = height - margin.top - margin.bottom;
 
 const xScale = scaleLinear ()
   .domain([0, max(data, d => d.COVID19)])
   .range([0,innerWidth]);
   console.log(xScale.range())
           
 const yScale = scaleBand ()
  .domain(data.map(d=> yValue(d)))
  .range([0,innerHeight])
  .padding(0.1);
  
 const yAxis = axisLeft(yScale);
 const xAxis = axisBottom(xScale)
   .tickFormat(format('.2s'));
  
 const g= svg.append('g')
   .attr('transform', `translate(${margin.left},${margin.top})`);
  
  g.append('g')
    .call(axisLeft(yScale))
    .selectAll('.domain, .tick line')
          .remove();

  
  g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d=>yScale(yValue(d)))
      .attr('width', d=> xScale(xValue(d)))      .attr('height',yScale.bandwidth());
  
    g.append('text')
    .text('TOP 10 Most COVID-19 Cases Countries');
};
d3.csv("data.csv").then(data => {
    data.forEach( d=> {
    d.COVID19 = +d.COVID19
});
   render(data);
});
